translate.storage.csvl10n.csvfile

Package translate :: Package storage :: Module csvl10n :: Class csvfile |
[hide private]
[frames] | no frames]

# Class csvfile

source code

This class represents a .csv file with various lines. The default format contains three columns: location, source, target

Nested Classes | [hide private]
| UnitClass The class of units that will be instantiated and used by this class

Instance Methods | [hide private]
__init__(self, inputfile=None, fieldnames=None, encoding="auto") Constructs a blank TranslationStore. | source code
parse(self, csvsrc) parser to process the given source string | source code
__str__(self) convert to a string. | source code
getoutput(self) | source code
Inherited from `base.TranslationStore`: `__getstate__`, `__setstate__`, `add_unit_to_index`, `addsourceunit`, `addunit`, `detect_encoding`, `findid`, `findunit`, `findunits`, `getids`, `getprojectstyle`, `getsourcelanguage`, `gettargetlanguage`, `getunits`, `isempty`, `makeindex`, `remove_unit_from_index`, `require_index`, `save`, `savefile`, `setprojectstyle`, `setsourcelanguage`, `settargetlanguage`, `translate`, `unit_iter` Inherited from `base.TranslationStore` (private): `_assignname` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Methods | [hide private]
Inherited from `base.TranslationStore`: `parsefile`, `parsestring`

Class Variables | [hide private]
| Name = `_("Comma Separated Value")` The human usable name of this store type
| Mimetypes = `['text/comma-separated-values', 'text/csv']` A list of MIME types associated with this store type
| Extensions = `["csv"]` A list of file extentions associated with this store type
Inherited from `base.TranslationStore`: `sourcelanguage`, `suggestions_in_format`, `targetlanguage` Inherited from `base.TranslationStore` (private): `_binary`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, inputfile=None, fieldnames=None, encoding="auto") (Constructor) | source code
Constructs a blank TranslationStore. Overrides: object.__init__ (inherited documentation)

### parse(self, csvsrc) | source code
parser to process the given source string Overrides: base.TranslationStore.parse (inherited documentation)

### __str__(self) (Informal representation operator) | source code
convert to a string. double check that unicode is handled somehow here Overrides: object.__str__